@@ -11,7 +11,7 @@ except ImportError:
     sys.exit(1)
 
 from github.utils import urlopen2, get_remote_info, edit_text, \
-    get_remote_info_from_option, get_prog, Pager
+    get_remote_info_from_option, get_prog, Pager, wrap_text
     
 def format_issue(issue, verbose=True):
     output = []
@@ -20,11 +20,18 @@ def format_issue(issue, verbose=True):
     else:
         indent = " " * (5 - len(str(issue['number'])))
     title = "%s%s. %s" % (indent, issue['number'], issue['title'])
-    output.append(title)
+    if not verbose:
+        output.append(title[:80])
     if verbose:
-        output.append("-" * len(title))
+        title = wrap_text(title)
+        output.append(title)
+        if len(title) > 79:
+            output.append("-" * 79)
+        else:
+            output.append("-" * len(title))
         if issue['body']:
-            output.append("%s" % issue['body'])
+            body = wrap_text(issue['body'])
+            output.append(body)
         output.append("    state: %s" % issue['state'])
         output.append("     user: %s" % issue['user'])
         output.append("    votes: %s" % issue['votes'])
@@ -260,25 +267,32 @@ def main():
     usage = """usage: %prog command [args] [options]
 
 Examples:
-%prog list [-s open|closed|all]          # show open, closed or all issues (default: open)
-%prog [-s o|c|a] -v                      # same as above, but with issue details
-%prog                                    # same as: %prog list
-%prog -v                                 # same as: %prog list -v
-%prog [-s o|c] -w                        # show issues' GitHub page in web browser (default: open)
-%prog show <nr>                          # show issue <nr>
-%prog <nr>                               # same as: %prog show <nr>
-%prog <nr> -w                            # show issue <nr>'s GitHub page in web browser
-%prog open (o)                           # create a new issue (with $EDITOR)
-%prog close (c) <nr>                     # close issue <nr>
-%prog open (o) <nr>                      # reopen issue <nr>
-%prog edit (e) <nr>                      # edit issue <nr> (with $EDITOR)
-%prog label add (al) <label> <nr>        # add <label> to issue <nr>
-%prog label remove (rl) <label> <nr>     # remove <label> from issue <nr>
-%prog search (s) <term> [-s open|closed] # search for <term> in open or closed issues (default: open)
-%prog s <term> [-s o|c] -v               # same as above, but with details
-%prog comment (m) <nr>                   # create a comment for issue <nr> (with $EDITOR)
-%prog -r <user>/<repo>                   # specify a repository (can be used for all commands)
-%prog -r <repo>                          # specify a repository (gets user from global git config)"""
+%prog list [-s open|closed|all]       show open, closed or all issues 
+                                    (default: open)
+%prog [-s o|c|a] -v                   same as above, but with issue details
+%prog                                 same as: %prog list
+%prog -v                              same as: %prog list -v
+%prog [-s o|c] -w                     show issues' GitHub page in web browser 
+                                    (default: open)
+%prog show <nr>                       show issue <nr>
+%prog <nr>                            same as: %prog show <nr>
+%prog <nr> -w                         show issue <nr>'s GitHub page in web 
+                                    browser
+%prog open (o)                        create a new issue (with $EDITOR)
+%prog close (c) <nr>                  close issue <nr>
+%prog open (o) <nr>                   reopen issue <nr>
+%prog edit (e) <nr>                   edit issue <nr> (with $EDITOR)
+%prog label add (al) <label> <nr>     add <label> to issue <nr>
+%prog label remove (rl) <label> <nr>  remove <label> from issue <nr>
+%prog search (s) <term>               search for <term> (default: open)
+%prog s <term> [-s o|c] -v            same as above, but with details
+%prog s <term> -s closed              only search in closed issues
+%prog comment (m) <nr>                create a comment for issue <nr> 
+                                    (with $EDITOR)
+%prog -r <user>/<repo>                specify a repository (can be used for 
+                                    all commands)
+%prog -r <repo>                       specify a repository (gets user from 
+                                    global git config)"""
     
     description = """Description:
 command-line interface to GitHub's Issues API (v2)"""
